pub enum ProviderRequest {
OpenCoordinator {
payload: ProviderOpenCoordinatorRequest,
responder: ProviderOpenCoordinatorResponder,
},
}Expand description
Provider for display coordinators.
The driver supports two simultaneous clients - a main client and a virtcon
client. In some cases, the provider service may provide access to only one or
the other; if the client tries to open the other then ZX_ERR_NOT_SUPPORTED will
be returned.
Variants
OpenCoordinator
Opens a client connection to the Display Coordinator.
On success, coordinator will be bound to the Display Coordinator
at the requested priority level, and coordinator_listener will receive
notifications for the newly bound client.
Fails with ZX_ERR_ALREADY_BOUND if the Display Coordinator already has
a connected client at the given priority level.
Fails with ZX_ERR_INVALID_ARGS if one of the required fields is missing.
Implementations
Sourceimpl ProviderRequest
impl ProviderRequest
pub fn into_open_coordinator( self, ) -> Option<(ProviderOpenCoordinatorRequest, ProviderOpenCoordinatorResponder)>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL