#[repr(C)]pub struct ClientPriority {
pub value: u32,
}Expand description
Decides which Display Coordinator client owns the displays.
The Display Coordinator has at most one connected client at each priority level. The client with the highest priority level owns the displays. Higher numerical values represent higher priorities.
[fuchsia.hardware.display/INVALID_CLIENT_PRIORITY_VALUE] is reserved as a
null value placeholder. Clients may not ask for this priority level when
connecting to the Coordinator.
Fields
value: u32Trait Implementations
Sourceimpl Clone for ClientPriority
impl Clone for ClientPriority
Sourcefn clone(&self) -> ClientPriority
fn clone(&self) -> ClientPriority
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ClientPriority
impl Debug for ClientPriority
Sourceimpl<D> Decode<ClientPriority, D> for ClientPrioritywhere
D: ResourceDialect,
impl<D> Decode<ClientPriority, D> for ClientPrioritywhere
D: ResourceDialect,
Sourcefn new_empty() -> ClientPriority
fn new_empty() -> ClientPriority
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<ClientPriority, D> for &ClientPrioritywhere
D: ResourceDialect,
impl<D> Encode<ClientPriority, D> for &ClientPrioritywhere
D: ResourceDialect,
Sourceimpl Hash for ClientPriority
impl Hash for ClientPriority
Sourceimpl Ord for ClientPriority
impl Ord for ClientPriority
Sourcefn cmp(&self, other: &ClientPriority) -> Ordering
fn cmp(&self, other: &ClientPriority) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ClientPriority
impl PartialEq for ClientPriority
Sourceimpl PartialOrd for ClientPriority
impl PartialOrd for ClientPriority
Sourceimpl TypeMarker for ClientPriority
impl TypeMarker for ClientPriority
Sourcetype Owned = ClientPriority
type Owned = ClientPriority
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for ClientPriority
impl ValueTypeMarker for ClientPriority
Sourcetype Borrowed<'a> = &'a ClientPriority
type Borrowed<'a> = &'a ClientPriority
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<ClientPriority as TypeMarker>::Owned,
) -> <ClientPriority as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<ClientPriority as TypeMarker>::Owned, ) -> <ClientPriority as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.impl Copy for ClientPriority
impl Eq for ClientPriority
impl Persistable for ClientPriority
impl StructuralPartialEq for ClientPriority