pub struct CoordinatorGetLatestCommittedConfigStampResponder { /* private fields */ }Implementations
Sourceimpl CoordinatorGetLatestCommittedConfigStampResponder
impl CoordinatorGetLatestCommittedConfigStampResponder
Sourcepub fn send(self, stamp: &ConfigStamp) -> Result<(), Error>
pub fn send(self, stamp: &ConfigStamp) -> Result<(), Error>
Sends a response to the FIDL transaction.
Sets the channel to shutdown if an error occurs.
Sourcepub fn send_no_shutdown_on_err(self, stamp: &ConfigStamp) -> Result<(), Error>
pub fn send_no_shutdown_on_err(self, stamp: &ConfigStamp) -> Result<(), Error>
Similar to “send” but does not shutdown the channel if an error occurs.