CoordinatorImportImageRequest

Struct CoordinatorImportImageRequest 

pub struct CoordinatorImportImageRequest {
    pub image_metadata: ImageMetadata,
    pub buffer_collection_id: BufferCollectionId,
    pub buffer_index: u32,
    pub image_id: ImageId,
}

Fields

image_metadata: ImageMetadata

Must be compatible with the arguments passed to [Coordinator.SetBufferCollectionConstraints] on the buffer_collection_id.

buffer_collection_id: BufferCollectionId

Identifies a previously imported BufferCollection.

The ID must be assigned to an imported BufferCollection, via a successful [Coordinator.ImportBufferCollection] call.

buffer_index: u32

Must be a valid index in the imported BufferCollection.

image_id: ImageId