pub struct ProviderSynchronousProxy { /* private fields */ }Implementations
Sourceimpl ProviderSynchronousProxy
impl ProviderSynchronousProxy
pub fn new(channel: Channel) -> Self
pub fn into_channel(self) -> Channel
Sourcepub fn wait_for_event(
&self,
deadline: MonotonicInstant,
) -> Result<ProviderEvent, Error>
pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<ProviderEvent, Error>
Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.
Sourcepub fn open_coordinator(
&self,
payload: ProviderOpenCoordinatorRequest,
___deadline: MonotonicInstant,
) -> Result<ProviderOpenCoordinatorResult, Error>
pub fn open_coordinator( &self, payload: ProviderOpenCoordinatorRequest, ___deadline: MonotonicInstant, ) -> Result<ProviderOpenCoordinatorResult, Error>
Opens a client connection to the Display Coordinator.
On success, coordinator will be bound to the Display Coordinator
at the requested priority level, and coordinator_listener will receive
notifications for the newly bound client.
Fails with ZX_ERR_ALREADY_BOUND if the Display Coordinator already has
a connected client at the given priority level.
Fails with ZX_ERR_INVALID_ARGS if one of the required fields is missing.